@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::Moai;
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 # ABSTRACT: Mojolicious UI components using modern UI libraries
 
 #pod =head1 SYNOPSIS
@@ -483,10 +483,10 @@ use Mojo::File qw( path );
 has config =>;
 sub register {
     my ( $self, $app, $config ) = @_;
-    my $library = $config->[0];
+    my $library = lc $config->[0];
     $self->config( $config->[1] || {} );
     $app->helper( moai => sub { $self } );
-    my $resources = path( __FILE__ )->sibling( 'Moai' )->child( 'resources' );
+    my $resources = path( __FILE__ )->sibling( 'Moai', 'resources' );
     push @{$app->renderer->paths},
         $resources->child( $library, 'templates' ),
         $resources->child( 'shared', 'templates' ),
@@ -506,7 +506,7 @@ Mojolicious::Plugin::Moai - Mojolicious UI components using modern UI libraries
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
